<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        title="创建签署项目"
        width="550px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="150px" >
        <el-form-item label="项目名称:" prop="itemName" >
          <el-input v-model="state.form.itemName" placeholder="请输入项目名称"></el-input>
        </el-form-item>

        <div style="display: flex;align-items: center;">

        <el-form-item label="最初签署人:" prop="deptId" >
            <el-cascader
                :show-all-levels="false"
                style="width: 170px"
                clearable
                placeholder="请选择部门"
                v-model="state.form.deptId"
                :options="state.options"
                @change="selectValue"
                :props="{ expandTrigger: 'hover', value: 'deptId',label: 'deptName',emitPath: false}">
            </el-cascader>
            <el-select
                clearable
                v-model="state.form.initiaiUserId"
                filterable
                remote
                reserve-keyword
                placeholder="请输入签署人名称"
                remote-show-suffix
                :remote-method="(val)=>getUserList(val,state.form.deptId)"
                style=" width:170px;margin-left:20px"
            >
              <el-option
                  v-for="item in state.userList"
                  :key="item.userId"
                  :label="item.nickName"
                  :value="item.userId"
              />
            </el-select>
        </el-form-item>
        </div>
      </el-form>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>创建项目</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import {ElMessage} from "element-plus";
import {listDept} from "@/api/system/dept";
import {listUser} from "@/api/system/user";
import {addSignProject} from "@/api/signAgreement/signProject";

const { proxy } = getCurrentInstance();
const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);

const state = reactive({
  form: {
    id: '',
    itemName: '',
    deptId: null,
    initiaiUserId: null,
    templateId: null
  },
  options: [],
  userList: [],
  formRules:{
    deptId: [{ required: true, trigger: "blur", message:'请选择部门' }],
    itemName: [{ required: true, trigger: "blur", message:'请输入项目名称' }],
  },
})


const openDialog = async (value) => {
  await getDept()
  state.form.templateId = value.id
  dialogVisible.value = true;
}
const selectValue = (val) => {
  state.userList = []
  state.form.initiaiUserId = null
  getUserList("",val)

}

const getDept = () => {
  listDept().then(response => {
    state.options = proxy.handleTree(response.data, "deptId",'parentId','children');
    console.log('response',state.options)
  });
}


const onSubmit = async () => {
  const valid = await busRef.value.validate();
  if(valid){
    const {id, ...data} = JSON.parse(JSON.stringify(state.form))
    if(data.initiaiUserId == null) {
      ElMessage.warning('请选择签署人')
      return;
    }
    const res = await addSignProject(data)
    if(res.code === 200){
      ElMessage({
        type: 'success',
        message: '新增成功'
      });
    }else{
      ElMessage.warning(res.message)
    }
    emit("getList")
    busRef.value.clearValidate();
    reset();
    dialogVisible.value = false;

  }
}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")
}
const reset = () => {
  state.form = {
    id: '',
    itemName: '',
    deptId: null,
    initiaiUserId: null,
    templateId: null
  }
}
const getUserList = async (val,deptId)=>{
  if(deptId == '' || deptId == null){
    // ElMessage.warning("请选择部门！")
    return;
  }
  if(val != ""){
    const queryParams = {
      deptId: deptId,
      nickName: val,
    }
    const res = await listUser(queryParams)
    if (res.code == 200) {
      state.userList = res.rows
    } else {
      ElMessage.warning(res.message)
    }
  }else {
    const queryParams = {
      pageNum: 1,
      pageSize: 10,
      deptId: deptId
    }
    const res = await listUser(queryParams)
    if (res.code == 200) {
      state.userList = res.rows
    } else {
      ElMessage.warning(res.message)
    }
  }
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
